#include <SPI.h>
#include <Wire.h>
#include <LiquidCrystal_I2C.h>

const int ledPin = 5;
float distance;
LiquidCrystal_I2C lcd(0x27, 16, 2);

volatile boolean spiReceived = false;

void setup() {
  Serial.begin(115200);
  SPI.begin();
  pinMode(SS, INPUT);
  pinMode(ledPin, OUTPUT);
  lcd.init();
  lcd.backlight();
  SPI.setDataMode(SPI_MODE0);
  SPI.attachInterrupt(); // Activer les interruptions SPI
}

ISR(SPI_STC_vect) {
  static byte dataBuffer[4];
  static int byteIndex = 0;

  dataBuffer[byteIndex] = SPDR;
  byteIndex++;

  if (byteIndex == 4) {
    memcpy(&distance, dataBuffer, sizeof(float));
    byteIndex = 0;
    spiReceived = true;
  }
}

void loop() {
  if (spiReceived) {
    spiReceived = false;

    // Affichage de la distance dans le moniteur série
    Serial.print("Distance: ");
    Serial.print(distance);
    Serial.println(" cm");

    // Affichage de la distance sur l'écran LCD
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Distance: ");
    lcd.setCursor(0, 1);
    lcd.print(distance);
    lcd.print(" cm");

    // Clignotement de la LED si la distance est inférieure à 50 cm
    if (distance < 50) {
      blinkLED();
    }
  }
}

void blinkLED() {
  for (int i = 0; i < 5; i++) {
    digitalWrite(ledPin, HIGH);
    delay(500);
    digitalWrite(ledPin, LOW);
    delay(500);
  }
}
